// 
// Module: CalMOSResponse
// Author: Hassan Siddiqui
//
// Description: 
// Provides a clean interface to CAL response data.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalMOSResponse.cc,v 1.2 2000/10/06 16:40:47 hsiddiqu Exp $

/* General */
#include <string>
#include <iostream>
#include <vector>

/* SAS-specific */
#include "Dal.h"
#include "CalServer.h"
#include "Redistribution.h"
#include "Tracer.h"

// Local classes
#include "CalMOSResponse.h"

/*****************************
 *
 * class CalMOSResponse
 *
 * Interface to CAL response data.
 *
 *****************************/


inline void CalMOSResponse::init()
{
  
  PROC;

  /* Currently set state for default EMOS settings */
  calServer.state()->node()->set(EMOScam::PRIMARY_NODE);
  
  /* Get response information */
  CanonicalRedist * rmf = 0; rmf = calServer.getAtom(rmf);
  _rmf = rmf;
  _rmf->at(300,300);

  
  ENDPROC;
}

/** Constructors */

/* Provides the entire range of 
 * redistribution available from the CAL */
CalMOSResponse::CalMOSResponse ( unsigned       lowerPI,
				 unsigned       nOutputChannels,
				 unsigned       outputChannelWidth,
                                 EventGrades    eventGrade)
{
  init();

  _eventGrade=eventGrade;

  createWithCalEbins(lowerPI, 
		     nOutputChannels, 
		     outputChannelWidth);
}  

/* Provides a restricted range */
CalMOSResponse::CalMOSResponse ( unsigned       lowerPI,
				 unsigned       nOutputChannels,
				 unsigned       outputChannelWidth,
				 const BinnedAxis * ebins,
                                 EventGrades    eventGrade)
{
  init();

  _eventGrade=eventGrade;

  createWithUserEbins( lowerPI, 
		       nOutputChannels, 
		       outputChannelWidth,
		       ebins);
}

/* Destructor */
CalMOSResponse::~CalMOSResponse()
{
  PROC;
  ENDPROC;
}

